# pyBlamscamp

This project has been renamed to [bandcrash](https://github.com/fluffy-critter/bandcrash). This package remains in existence as a redirection wrapper to that; its long-term support is not guaranteed.

